@@ -1,17 +1,18 @@
-from .stream import Stream
-from ..compat import urljoin, queue
-from ..exceptions import StreamError
-from ..utils import urlget, RingBuffer, absolute_url
+import io
+import re
 
-from time import time, sleep
+from time import time
 from threading import Lock, Thread, Timer
 
-import io
-import os.path
-import re
+from .stream import Stream
+from ..buffers import RingBuffer
+from ..compat import queue
+from ..exceptions import StreamError
+from ..utils import urlget, absolute_url
 
 try:
     from Crypto.Cipher import AES
+
     import struct
 
     def num_to_iv(n):
@@ -307,6 +308,15 @@ class HLSStreamIO(io.IOBase):
 
 
 class HLSStream(Stream):
+    """
+    Implementation of the Apple HTTP Live Streaming protocol
+
+    *Attributes:*
+
+    - :attr:`url` URL to the m3u8 playlist
+
+    """
+
     __shortname__ = "hls"
 
     def __init__(self, session, url):
